using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;


namespace MediaTest
{
    enum StartZone 
    {
        Center,
        TopLeft,
        Top,
        TopRight,
        Right,
        BottomRight,
        Bottom,
        BottomLeft,
        Left
    }

    public enum Mode 
    {
        Move,
        Menu
    }

    /// <summary>
    /// Summary description for Form1.
    /// </summary>
    public class Form1 : System.Windows.Forms.Form
    {
        private AxMediaPlayer.AxMediaPlayer axMediaPlayer1;
        /// <summary>
        /// Required designer variable.
        /// </summary>
        private System.ComponentModel.Container components = null;
        private MenuForm menuForm;
        private int startX, startY; // Used in the Move mode
        private StartZone startZone = StartZone.Center; // Used in the Move mode
        public Mode _mode;
		
        public Mode mode 
        {
            get { return _mode; }
            set 
            {
                switch (value) 
                {
                    case Mode.Move:
                        axMediaPlayer1.MouseUpEvent -= new AxMediaPlayer._MediaPlayerEvents_MouseUpEventHandler(MenuMode_MouseUp);
                        axMediaPlayer1.MouseDownEvent +=
                            new AxMediaPlayer._MediaPlayerEvents_MouseDownEventHandler(MoveMode_MouseDown);
                        axMediaPlayer1.MouseMoveEvent +=
                            new AxMediaPlayer._MediaPlayerEvents_MouseMoveEventHandler(MoveMode_MouseMove);
                        axMediaPlayer1.MouseUpEvent +=
                            new AxMediaPlayer._MediaPlayerEvents_MouseUpEventHandler(MoveMode_MouseUp);

                        break;
                    case Mode.Menu:
                        axMediaPlayer1.MouseUpEvent += new AxMediaPlayer._MediaPlayerEvents_MouseUpEventHandler(MenuMode_MouseUp);
                        axMediaPlayer1.MouseDownEvent -=
                            new AxMediaPlayer._MediaPlayerEvents_MouseDownEventHandler(MoveMode_MouseDown);
                        axMediaPlayer1.MouseMoveEvent -=
                            new AxMediaPlayer._MediaPlayerEvents_MouseMoveEventHandler(MoveMode_MouseMove);
                        axMediaPlayer1.MouseUpEvent -=
                            new AxMediaPlayer._MediaPlayerEvents_MouseUpEventHandler(MoveMode_MouseUp);
                        break;
                }
                _mode = value;
            }

        }


        public Form1()
        {
            //
            // Required for Windows Form Designer support
            //
            InitializeComponent();
            //
            // TODO: Add any constructor code after InitializeComponent call
            //
            axMediaPlayer1.EnableFullScreenControls = true;
            axMediaPlayer1.AutoSize = true;
            axMediaPlayer1.Width = this.Width;
            axMediaPlayer1.Height = this.Height;
            axMediaPlayer1.VideoBorderWidth = 0;

            this.Resize += new EventHandler(form_Resize);

            menuForm = new MenuForm(this);
            mode = Mode.Move;
        }

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        protected override void Dispose( bool disposing )
        {
            if( disposing )
            {
                if (components != null) 
                {
                    components.Dispose();
                }
            }
            base.Dispose( disposing );
        }

		#region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(Form1));
            this.axMediaPlayer1 = new AxMediaPlayer.AxMediaPlayer();
            ((System.ComponentModel.ISupportInitialize)(this.axMediaPlayer1)).BeginInit();
            this.SuspendLayout();
            // 
            // axMediaPlayer1
            // 
            this.axMediaPlayer1.Name = "axMediaPlayer1";
            this.axMediaPlayer1.OcxState = ((System.Windows.Forms.AxHost.State)(resources.GetObject("axMediaPlayer1.OcxState")));
            this.axMediaPlayer1.Size = new System.Drawing.Size(512, 392);
            this.axMediaPlayer1.TabIndex = 0;
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(552, 405);
            this.Controls.AddRange(new System.Windows.Forms.Control[] {
                                                                          this.axMediaPlayer1});
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.None;
            this.Name = "Form1";
            this.Text = "Form1";
            ((System.ComponentModel.ISupportInitialize)(this.axMediaPlayer1)).EndInit();
            this.ResumeLayout(false);

        }
		#endregion

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main() 
        {
            Application.Run(new Form1());
        }

        private void MenuMode_MouseUp(object sender, AxMediaPlayer._MediaPlayerEvents_MouseUpEvent e)
        {
            if (menuForm.Visible) 
            {
                menuForm.MyHide();
                mode = Mode.Move;
                Console.WriteLine("hide");
            }
			
            return;
        }

        private void MoveMode_MouseDown(object sender, AxMediaPlayer._MediaPlayerEvents_MouseDownEvent e)
        {
            if ((e.button & 1) != 0)
            { // Left click
                startX = e.x;
                startY = e.y;

                Console.WriteLine("down");
                // TODO: depending on the location of the click, set the startZone
                startZone = FindZone(e.x, e.y);
                SetCursor(startZone);
            }

            return; 
        }

        private void MoveMode_MouseUp(object sender, AxMediaPlayer._MediaPlayerEvents_MouseUpEvent e)
        {
            if ((e.button & 1) != 0)
            { // Left button
                SetCursor(FindZone(e.x, e.y));
            }
            if ((e.button & 2) != 0)
            { // Right button
                // Go into Menu mode
                mode = Mode.Menu;
                if (!menuForm.Visible)
                {
                    menuForm.Location = this.Location;
                    menuForm.Size = this.Size;
                    menuForm.Show(new Point(e.x, e.y));
                    menuForm.Location = this.Location;
                    menuForm.Size = this.Size;
                }
            }

            return; 
        }

        private void MoveMode_MouseMove(object sender, AxMediaPlayer._MediaPlayerEvents_MouseMoveEvent e)
        {
            if ((e.button & 1) != 0) 
            { // Left button
                System.Drawing.Point p = this.Location;
                System.Drawing.Size s = this.Size;
                SetCursor(startZone);

                switch (startZone) 
                {
                    case StartZone.Center:
                        p.X += (e.x - startX);
                        p.Y += (e.y - startY);
                        if (Math.Abs(e.x - startX) > 0 || Math.Abs(e.y - startY) > 0) 
                        {
                            this.Location = p;
                        }
                        break;

                    case StartZone.Top:
                        p.Y += (e.y - startY);
                        s.Height -= (e.y - startY);
                        if (e.y > startY)
                        {
                            this.Size = s;
                            this.Location = p;
                        }
                        else if (e.y < startY)
                        {
                            this.Location = p;
                            this.Size = s;
                        }
                        break;

                    case StartZone.TopRight:
                        p.Y += (e.y - startY);
                        s.Height -= (e.y - startY);
                        s.Width += (e.x - startX);
                        this.Size = s;
                        this.Location = p;
                        startX = e.x;
                        break;

                    case StartZone.Right:
                        s.Width += (e.x - startX);
                        this.Size = s;
                        startX = e.x;
                        break;

                    case StartZone.BottomRight:
                        s.Height += (e.y - startY);
                        s.Width += (e.x - startX);
                        this.Size = s;
                        startY = e.y;
                        startX = e.x;
                        break;

                    case StartZone.Bottom:
                        s.Height += (e.y - startY);
                        if (e.y - startY > 0) 
                        {
                            this.Size = s;
                            startY = e.y;
                        } 
                        else if (e.y - startY < 0) 
                        {
                            startY = e.y;
                            this.Size = s;
                        }
                        break;

                    case StartZone.BottomLeft:
                        s.Height += (e.y - startY);
                        p.X += (e.x - startX);
                        s.Width -= (e.x - startX);
                        startY = e.y;
                        this.Location = p;
                        this.Size = s;

                        break;

                    case StartZone.Left:
                        p.X += (e.x - startX);
                        s.Width -= (e.x - startX);
                        if (e.x > startX) 
                        {
                            this.Size = s;
                            this.Location = p;
                        }
                        else if (e.x < startX) 
                        {
                            this.Location = p;
                            this.Size = s;
                        }
                        break;
					
                    case StartZone.TopLeft:
                        p.X += (e.x - startX);
                        p.Y += (e.y - startY);
                        s.Width -= (e.x - startX);
                        s.Height -= (e.y - startY);
                        this.Size = s;
                        this.Location = p;
                        break;

                    default:
                        break;
                }
            }
            else if (e.button == 0) 
            {
                // Depending on position show a different cursor
                StartZone curZone = FindZone(e.x, e.y);
                SetCursor(curZone);
            }

            return; 
        }

        private void form_Resize(object sender, System.EventArgs e)
        {
            axMediaPlayer1.Width = this.Width;
            axMediaPlayer1.Height = this.Height;
        }

        public void Play() 
        {
            axMediaPlayer1.Play();
        }

        public void Pause() 
        {
            axMediaPlayer1.Pause();
        }

        public void OpenFile() 
        {            

            OpenFileDialog openFileDialog = new OpenFileDialog();

            openFileDialog.Filter = "Media Files|*.mpg;*.avi;*.wma;*.mov;*.wav;*.mp2;*.mp3|All Files|*.*";

            if (DialogResult.OK == openFileDialog.ShowDialog())
            {
                axMediaPlayer1.Open(openFileDialog.FileName);
            }

            //axMediaPlayer1.Open("c:\\burn\\Stigmata.avi");
        }

        public void CloseFile() 
        {
            // TODO: close movie file
            axMediaPlayer1.Stop();
        }

        private void SetCursor(StartZone zone) 
        {
            switch (zone) 
            {
                case StartZone.Top:
                case StartZone.Bottom:
                    Cursor.Current = Cursors.SizeNS;
                    break;
                case StartZone.Left:
                case StartZone.Right:
                    Cursor.Current = Cursors.SizeWE;
                    break;
                case StartZone.TopLeft:
                case StartZone.BottomRight:
                    Cursor.Current = Cursors.SizeNWSE;
                    break;
                case StartZone.TopRight:
                case StartZone.BottomLeft:
                    Cursor.Current = Cursors.SizeNESW;
                    break;
                case StartZone.Center:
                    Cursor.Current = Cursors.SizeAll;
                    break;
            }
        }

        private StartZone FindZone(int x, int y) 
        {
            // depending on the cursor
            int height = this.Size.Height;
            int width = this.Size.Width;

            int horIndex = 0;
            if (3 * x > 2 * width) 
            {
                horIndex = 2;
            } 
            else if (3 * x > width)
            {
                horIndex = 1;
            }

            int verIndex = 0;
            if (3 * y > 2 * height) 
            {
                verIndex = 2;
            } 
            else if (3 * y > height)
            {
                verIndex = 1;
            }

            return zones[verIndex, horIndex];
        }
        static StartZone[,]zones = new StartZone[3,3] 
            {
                    { StartZone.TopLeft, StartZone.Top, StartZone.TopRight }, 
             { StartZone.Left, StartZone.Center, StartZone.Right },
             { StartZone.BottomLeft, StartZone.Bottom, StartZone.BottomRight}};

    }
}
